# Web of Life 2 (WoL2) and Earth Microbiome Project (EMP)

The KEGG and EggNOG gene families from the 1,510 genomes from the WoL2 and 793 metagenome-assembled genomes are available in [Zenodo](https://doi.org/10.5281/zenodo.15020140).